@@ -1,17 +1,20 @@
 """Provides the prefix() function for finding cola resources"""
 import os
-import glob
+import webbrowser
+from os.path import dirname
 
-_modpath = os.path.abspath(__file__)
-if 'share' in __file__ and 'lib' in __file__:
+from cola import core
+
+_modpath = core.abspath(__file__)
+if os.path.join('share', 'git-cola', 'lib') in _modpath:
     # this is the release tree
     # __file__ = '$prefix/share/git-cola/lib/cola/__file__.py'
-    _lib_dir = os.path.dirname(os.path.dirname(_modpath))
-    _prefix = os.path.dirname(os.path.dirname(os.path.dirname(_lib_dir)))
+    _lib_dir = dirname(dirname(_modpath))
+    _prefix = dirname(dirname(dirname(_lib_dir)))
 else:
     # this is the source tree
     # __file__ = '$prefix/cola/__file__.py'
-    _prefix = os.path.dirname(os.path.dirname(_modpath))
+    _prefix = dirname(dirname(_modpath))
 
 
 def prefix(*args):
@@ -29,11 +32,15 @@ def html_docs():
     # index.html only exists after the install-docs target is run,
     # so fallback to git-cola.txt.
     htmldocs = doc('html', 'index.html')
-    if os.path.exists(htmldocs):
+    if core.exists(htmldocs):
         return htmldocs
     return doc('git-cola.txt')
 
 
+def show_html_docs():
+    url = html_docs()
+    webbrowser.open_new_tab(url)
+
 def share(*args):
     """Return a path relative to cola's /usr/share/ directory"""
     return prefix('share', 'git-cola', *args)
@@ -41,23 +48,9 @@ def share(*args):
 
 def icon(basename):
     """Return the full path to an icon file given a basename."""
-    return share('icons', basename)
+    return 'icons:'+basename
 
 
-def stylesheet(name):
-    """Return a path relative to cola's /usr/share/../styles directory"""
-    stylesheet = share('styles', name + '.qss')
-    if os.path.exists(stylesheet):
-        return stylesheet
-    else:
-        return None
-
-
-def style_dir():
+def icon_dir():
     """Return the path to the style dir within the cola install tree."""
-    return share('styles')
-
-
-def resource_dirs(path):
-    """Returns directories beneath a specific path"""
-    return [p for p in glob.glob(os.path.join(path, '*')) if os.path.isdir(p)]
+    return share('icons')
